//
// library.js - handle SQLite3 database
//
// 1 Dec, 2018 by FUJIWARA Teruyoshi <tf@dsl.gr.jp>
//
const sqlite3 = require('sqlite3');
const fs = require('fs');
require('./const.js');

function db_open() {
  return new sqlite3.Database(SQL_DB);
}

function db_close(db) {
  db.close();
}

function db_log(db) {
  db.each('SELECT * FROM lifelog', function (err, row) {
    msg = formatByArray('{0},{1},{2},{3}', row.date, row.time, row.type, row.value);
    console.log(msg);
  });
}

function db_dump(db, file) {
  var result = '';

  db.all('SELECT * FROM lifelog', (err, rows) => {
    rows.forEach((row) => {
      var str = formatByArray('{0},{1},{2},{3}', row.date, row.time, row.type, row.value);
      result = result + str + '\n';
    });
    fs.writeFile(file, result, (err) => {
      if (err) {
        console.log('Write error: ' + err);
      }
    });
  });
}
function db_add(type, value) {
  var dt = new Date();
  var date_formatted = dt.toFormat('YYYY/MM/DD');
  var time_formatted = dt.toFormat('HH24:MI:SS');
  var result = true;
  
  if (!checkValue(value)) {
    return false;
  }
  db.run('INSERT INTO lifelog VALUES ($date_formatted, $time_formatted, $type, $value)',
	{$date_formatted: date_formatted,
          $time_formatted: time_formatted,
          $type: type,
          $value: value},
         (error, row) => {
           if (error) {
             result = false;
           }});
  return result;
}

function formatByArray(msg) {
  var args = [];
  
  for (var i = 1; i < arguments.length; i++) {
    args[i - 1] = arguments[i];
  }
  return msg.replace(/\{(\d+)\}/g, function (m, k) {
    return args[k];
  });
};

function checkValue(value) {
  return (/^[0-9]+(\.[0-9]+)?$/.test(value));
}

global.db_open = db_open;
global.db_close = db_close;
global.db_add = db_add;
global.db_log = db_log;
global.db_dump = db_dump;
